==> redux-solid-0.6.2.tgz: package/src/_dev/index.ts <==
import store from "./createStore";

store.dispatch({
    "type": "add/replace_StockWatchs",
    "data": [{
        "isin": "IRO1FOLD0001",
        "last": 2494,
        "closing": 2500,
        "first": 2378,
        "high": 2583,
        "low": 2392,
        "min": 2372,
        "max": 2620,
        "tradeValue": 27559,
        "tradeVolume": 10682756,
        "tradesCount": 1438,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": -2,
        "closingVariation": 4,
        "lastVariationPercentage": -0.08,
        "closingVariationPercentage": 0.16
    }]
});


// store.dispatch({
//     "type": "add/replace_Instruments",
//     "data": [{
//         "id": "IRR3BNOP0101",
//         "name": "نوینح",
//         "englishName": "BNOX1",
//         "description": "بیمه نوین",
//         "totalShares": 0,
//         "baseVolume": 1,
//         "minOrderCount": 1,
//         "maxOrderCount": 50000,
//         "tseId": 70335773040403700,
//         "sector": {"code": "66", "name": "بیمه وصندوق بازنشستگی به جزتامین اجتماعی", "superSectorCode": "0001"},
//         "subSector": {"code": "6611", "sectorCode": "66", "name": "فعالیتهای مالی و اجرائی"},
//         "board": {"code": "3", "name": "تابلو فرعی"},
//         "marketCode": "MARKET_Z1",
//         "marketName": "بازار اول فرابورس",
//         "validity": "VALID",
//         "createdAt": "2018-12-19T06:15:41",
//         "updatedAt": "2018-12-19T07:00:34",
//         "freeFloat": 0
//     }]
// });


store.dispatch({
    "type": "add/replace_StockWatchs",
    "data": [{
        "isin": "IRO1FOLD0001",
        "last": 2499,
        "closing": 2493,
        "first": 2368,
        "high": 2584,
        "low": 2399,
        "min": 2372,
        "max": 2620,
        "tradeValue": 60721,
        "tradeVolume": 11224793,
        "tradesCount": 1212,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 3,
        "closingVariation": -3,
        "lastVariationPercentage": 0.12,
        "closingVariationPercentage": -0.12
    }, {
        "isin": "IRO1BROJ0001",
        "last": 2493,
        "closing": 2505,
        "first": 2380,
        "high": 2591,
        "low": 2401,
        "min": 2372,
        "max": 2620,
        "tradeValue": 38754,
        "tradeVolume": 18589508,
        "tradesCount": 1221,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": -3,
        "closingVariation": 9,
        "lastVariationPercentage": -0.12,
        "closingVariationPercentage": 0.36
    }, {
        "isin": "IRR1BROJ0101",
        "last": 2504,
        "closing": 2493,
        "first": 2371,
        "high": 2582,
        "low": 2393,
        "min": 2372,
        "max": 2620,
        "tradeValue": 21024,
        "tradeVolume": 25578136,
        "tradesCount": 1073,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 8,
        "closingVariation": -3,
        "lastVariationPercentage": 0.32,
        "closingVariationPercentage": -0.12
    }, {
        "isin": "IRO1NBRS0001",
        "last": 2489,
        "closing": 2489,
        "first": 2376,
        "high": 2597,
        "low": 2405,
        "min": 2372,
        "max": 2620,
        "tradeValue": 50480,
        "tradeVolume": 21277800,
        "tradesCount": 1456,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": -7,
        "closingVariation": -7,
        "lastVariationPercentage": -0.28,
        "closingVariationPercentage": -0.28
    }, {
        "isin": "IRO7PTOP0001",
        "last": 2496,
        "closing": 2491,
        "first": 2377,
        "high": 2584,
        "low": 2402,
        "min": 2372,
        "max": 2620,
        "tradeValue": 49124,
        "tradeVolume": 12016485,
        "tradesCount": 2419,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 0,
        "closingVariation": -5,
        "lastVariationPercentage": 0,
        "closingVariationPercentage": -0.2
    }, {
        "isin": "IRO3ZF770001",
        "last": 2502,
        "closing": 2502,
        "first": 2374,
        "high": 2589,
        "low": 2406,
        "min": 2372,
        "max": 2620,
        "tradeValue": 41598,
        "tradeVolume": 14482520,
        "tradesCount": 1154,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 6,
        "closingVariation": 6,
        "lastVariationPercentage": 0.24,
        "closingVariationPercentage": 0.24
    }, {
        "isin": "IRO7KPAP0001",
        "last": 2491,
        "closing": 2484,
        "first": 2367,
        "high": 2591,
        "low": 2404,
        "min": 2372,
        "max": 2620,
        "tradeValue": 45240,
        "tradeVolume": 21665550,
        "tradesCount": 2267,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": -5,
        "closingVariation": -12,
        "lastVariationPercentage": -0.2,
        "closingVariationPercentage": -0.48
    }, {
        "isin": "IRO3ANQZ0001",
        "last": 2502,
        "closing": 2486,
        "first": 2378,
        "high": 2584,
        "low": 2397,
        "min": 2372,
        "max": 2620,
        "tradeValue": 53796,
        "tradeVolume": 16145273,
        "tradesCount": 1164,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 6,
        "closingVariation": -10,
        "lastVariationPercentage": 0.24,
        "closingVariationPercentage": -0.4
    }, {
        "isin": "IRO3Z0290001",
        "last": 2502,
        "closing": 2497,
        "first": 2379,
        "high": 2590,
        "low": 2393,
        "min": 2372,
        "max": 2620,
        "tradeValue": 40787,
        "tradeVolume": 15478501,
        "tradesCount": 1679,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 6,
        "closingVariation": 1,
        "lastVariationPercentage": 0.24,
        "closingVariationPercentage": 0.04
    }, {
        "isin": "IRO1MRIN0001",
        "last": 2492,
        "closing": 2489,
        "first": 2367,
        "high": 2586,
        "low": 2405,
        "min": 2372,
        "max": 2620,
        "tradeValue": 60616,
        "tradeVolume": 21602696,
        "tradesCount": 2617,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": -4,
        "closingVariation": -7,
        "lastVariationPercentage": -0.16,
        "closingVariationPercentage": -0.28
    }]
});

==> redux-solid-0.7.0.tgz: package/src/_dev/index.ts <==
import store from "./createStore";

store.dispatch({
    "type": "add/replace_myMap",
    "data": [{
        "isin": "IRO1FOLD0001",
        "last": 2494,
        "closing": 2500,
        "first": 2378,
        "high": 2583,
        "low": 2392,
        "min": 2372,
        "max": 2620,
        "tradeValue": 27559,
        "tradeVolume": 10682756,
        "tradesCount": 1438,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": -2,
        "closingVariation": 4,
        "lastVariationPercentage": -0.08,
        "closingVariationPercentage": 0.16
    }]
});


store.dispatch({
    "type": "add/replace_myMap2",
    "data": [{
        "id": "IRR3BNOP0101",
        "name": "نوینح",
        "englishName": "BNOX1",
        "description": "بیمه نوین",
        "totalShares": 0,
        "baseVolume": 1,
        "minOrderCount": 1,
        "maxOrderCount": 50000,
        "tseId": 70335773040403700,
        "sector": {"code": "66", "name": "بیمه وصندوق بازنشستگی به جزتامین اجتماعی", "superSectorCode": "0001"},
        "subSector": {"code": "6611", "sectorCode": "66", "name": "فعالیتهای مالی و اجرائی"},
        "board": {"code": "3", "name": "تابلو فرعی"},
        "marketCode": "MARKET_Z1",
        "marketName": "بازار اول فرابورس",
        "validity": "VALID",
        "createdAt": "2018-12-19T06:15:41",
        "updatedAt": "2018-12-19T07:00:34",
        "freeFloat": 0
    }]
});


store.dispatch({
    "type": "add/replace_myMap",
    "data": [{
        "isin": "IRO1FOLD0001",
        "last": 2499,
        "closing": 2493,
        "first": 2368,
        "high": 2584,
        "low": 2399,
        "min": 2372,
        "max": 2620,
        "tradeValue": 60721,
        "tradeVolume": 11224793,
        "tradesCount": 1212,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 3,
        "closingVariation": -3,
        "lastVariationPercentage": 0.12,
        "closingVariationPercentage": -0.12
    }, {
        "isin": "IRO1BROJ0001",
        "last": 2493,
        "closing": 2505,
        "first": 2380,
        "high": 2591,
        "low": 2401,
        "min": 2372,
        "max": 2620,
        "tradeValue": 38754,
        "tradeVolume": 18589508,
        "tradesCount": 1221,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": -3,
        "closingVariation": 9,
        "lastVariationPercentage": -0.12,
        "closingVariationPercentage": 0.36
    }, {
        "isin": "IRR1BROJ0101",
        "last": 2504,
        "closing": 2493,
        "first": 2371,
        "high": 2582,
        "low": 2393,
        "min": 2372,
        "max": 2620,
        "tradeValue": 21024,
        "tradeVolume": 25578136,
        "tradesCount": 1073,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 8,
        "closingVariation": -3,
        "lastVariationPercentage": 0.32,
        "closingVariationPercentage": -0.12
    }, {
        "isin": "IRO1NBRS0001",
        "last": 2489,
        "closing": 2489,
        "first": 2376,
        "high": 2597,
        "low": 2405,
        "min": 2372,
        "max": 2620,
        "tradeValue": 50480,
        "tradeVolume": 21277800,
        "tradesCount": 1456,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": -7,
        "closingVariation": -7,
        "lastVariationPercentage": -0.28,
        "closingVariationPercentage": -0.28
    }, {
        "isin": "IRO7PTOP0001",
        "last": 2496,
        "closing": 2491,
        "first": 2377,
        "high": 2584,
        "low": 2402,
        "min": 2372,
        "max": 2620,
        "tradeValue": 49124,
        "tradeVolume": 12016485,
        "tradesCount": 2419,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 0,
        "closingVariation": -5,
        "lastVariationPercentage": 0,
        "closingVariationPercentage": -0.2
    }, {
        "isin": "IRO3ZF770001",
        "last": 2502,
        "closing": 2502,
        "first": 2374,
        "high": 2589,
        "low": 2406,
        "min": 2372,
        "max": 2620,
        "tradeValue": 41598,
        "tradeVolume": 14482520,
        "tradesCount": 1154,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 6,
        "closingVariation": 6,
        "lastVariationPercentage": 0.24,
        "closingVariationPercentage": 0.24
    }, {
        "isin": "IRO7KPAP0001",
        "last": 2491,
        "closing": 2484,
        "first": 2367,
        "high": 2591,
        "low": 2404,
        "min": 2372,
        "max": 2620,
        "tradeValue": 45240,
        "tradeVolume": 21665550,
        "tradesCount": 2267,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": -5,
        "closingVariation": -12,
        "lastVariationPercentage": -0.2,
        "closingVariationPercentage": -0.48
    }, {
        "isin": "IRO3ANQZ0001",
        "last": 2502,
        "closing": 2486,
        "first": 2378,
        "high": 2584,
        "low": 2397,
        "min": 2372,
        "max": 2620,
        "tradeValue": 53796,
        "tradeVolume": 16145273,
        "tradesCount": 1164,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 6,
        "closingVariation": -10,
        "lastVariationPercentage": 0.24,
        "closingVariationPercentage": -0.4
    }, {
        "isin": "IRO3Z0290001",
        "last": 2502,
        "closing": 2497,
        "first": 2379,
        "high": 2590,
        "low": 2393,
        "min": 2372,
        "max": 2620,
        "tradeValue": 40787,
        "tradeVolume": 15478501,
        "tradesCount": 1679,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": 6,
        "closingVariation": 1,
        "lastVariationPercentage": 0.24,
        "closingVariationPercentage": 0.04
    }, {
        "isin": "IRO1MRIN0001",
        "last": 2492,
        "closing": 2489,
        "first": 2367,
        "high": 2586,
        "low": 2405,
        "min": 2372,
        "max": 2620,
        "tradeValue": 60616,
        "tradeVolume": 21602696,
        "tradesCount": 2617,
        "referencePrice": 2496,
        "state": "A",
        "event": "CLOSING_PRICE",
        "upRangeCount": 5,
        "downRangeCount": 5,
        "dateTime": "2019-11-09T17:15:09",
        "lastTrade": "2019-11-05T12:50:53",
        "lastVariation": -4,
        "closingVariation": -7,
        "lastVariationPercentage": -0.16,
        "closingVariationPercentage": -0.28
    }]
});
